==> aspose_words_cloud-20.10.3.tar.gz: test/document/revisions_tests.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="revisions_tests.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

import 'package:aspose_words_cloud/aspose_words_cloud.dart';

import '../test_context.dart';

/// Example of how to accept all revisions in document.
class RevisionsTests {
  final TestContext context;
  String remoteDataFolder;
  String localFile;

  RevisionsTests(final this.context) {
    remoteDataFolder =
        context.remoteBaseTestDataFolder + '/DocumentActions/Revisions';
    localFile = 'Common/test_multi_pages.docx';
  }

  /// Test for accepting revisions in document.
  Future<void> testAcceptAllRevisions() async {
    final remoteFileName = 'TestAcceptAllRevisions.docx';
    await context.uploadFile(
        localFile, remoteDataFolder + '/' + remoteFileName);

    final request = AcceptAllRevisionsRequest(remoteFileName,
        folder: remoteDataFolder,
        destFileName: context.baseTestOutPath + '/' + remoteFileName);

    await context.getApi().acceptAllRevisions(request);
  }

  /// Test for rejecting revisions in document.
  Future<void> testRejectAllRevisions() async {
    final remoteFileName = 'TestRejectAllRevisions.docx';
    await context.uploadFile(
        localFile, remoteDataFolder + '/' + remoteFileName);

    final request = RejectAllRevisionsRequest(remoteFileName,
        folder: remoteDataFolder,
        destFileName: context.baseTestOutPath + '/' + remoteFileName);

    await context.getApi().rejectAllRevisions(request);
  }
}

==> aspose_words_cloud-21.1.0.tar.gz: test/document/revisions_tests.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="revisions_tests.dart">
 *   Copyright (c) 2021 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

import 'package:aspose_words_cloud/aspose_words_cloud.dart';
import 'package:test/test.dart';

import '../test_context.dart';

/// Example of how to accept all revisions in document.
class RevisionsTests {
  final TestContext context;
  String remoteDataFolder;
  String localFile;

  RevisionsTests(final this.context) {
    remoteDataFolder =
        context.remoteBaseTestDataFolder + '/DocumentActions/Revisions';
    localFile = 'Common/test_multi_pages.docx';
  }

  /// Test for accepting revisions in document.
  Future<void> testAcceptAllRevisions() async {
    final remoteFileName = 'TestAcceptAllRevisions.docx';
    await context.uploadFile(
        localFile, remoteDataFolder + '/' + remoteFileName);

    final request = AcceptAllRevisionsRequest(remoteFileName,
        folder: remoteDataFolder,
        destFileName: context.baseTestOutPath + '/' + remoteFileName);

    var result = await context.getApi().acceptAllRevisions(request);
    expect(result.result, isNotNull);
    expect(result.result.dest, isNotNull);
  }

  /// Test for accepting revisions in document online.
  Future<void> testAcceptAllRevisionsOnline() async {
    final request = AcceptAllRevisionsOnlineRequest(
        await context.loadBinaryFile(localFile));

    await context.getApi().acceptAllRevisionsOnline(request);
  }

  /// Test for rejecting revisions in document.
  Future<void> testRejectAllRevisions() async {
    final remoteFileName = 'TestRejectAllRevisions.docx';
    await context.uploadFile(
        localFile, remoteDataFolder + '/' + remoteFileName);

    final request = RejectAllRevisionsRequest(remoteFileName,
        folder: remoteDataFolder,
        destFileName: context.baseTestOutPath + '/' + remoteFileName);

    var result = await context.getApi().rejectAllRevisions(request);
    expect(result.result, isNotNull);
    expect(result.result.dest, isNotNull);
  }

  /// Test for rejecting revisions in document online.
  Future<void> testRejectAllRevisionsOnline() async {
    final request = RejectAllRevisionsOnlineRequest(
        await context.loadBinaryFile(localFile));

    await context.getApi().rejectAllRevisionsOnline(request);
  }
}
